BootpayWebView class

Inheritance

Constructors

BootpayWebView({Key? key, Payload? payload, bool? showCloseButton, BootpayDefaultCallback? onCancel, BootpayDefaultCallback? onError, BootpayCloseCallback? onClose, BootpayDefaultCallback? onIssued, BootpayConfirmCallback? onConfirm, BootpayAsyncConfirmCallback? onConfirmAsync, BootpayDefaultCallback? onDone, WidgetResizeCallback? onWidgetResize, Widget? closeButton, String? userAgent, int? requestType})

Properties

cancelEventHandler → String
no setter
changeMethodWatch → String
no setter
changeTermsWatch → String
no setter
closeBridgeScript → String
no setter
closeButton ↔ Widget?
getter/setter pair
closeController → DebounceCloseController
final
closeEventHandler → String
no setter
confirmEventHandler → String
no setter
doneEventHandler → String
no setter
errorEventHandler → String
no setter
firstPageLoad ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
INAPP_URL → String
final
issuedEventHandler → String
no setter
isWidget ↔ bool?
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
final
onCancel ↔ BootpayDefaultCallback?
getter/setter pair
onClose ↔ BootpayCloseCallback?
getter/setter pair
onCloseWidget ↔ BootpayCloseCallback?
getter/setter pair
onConfirm ↔ BootpayConfirmCallback?
getter/setter pair
onConfirmAsync ↔ BootpayAsyncConfirmCallback?
getter/setter pair
onDone ↔ BootpayDefaultCallback?
getter/setter pair
onError ↔ BootpayDefaultCallback?
getter/setter pair
onFullSizeScreen ↔ BootpayDefaultCallback?
getter/setter pair
onIssued ↔ BootpayDefaultCallback?
getter/setter pair
onProgressShow ↔ BootpayProgressBarCallback?
getter/setter pair
onRevertScreen ↔ BootpayDefaultCallback?
getter/setter pair
onWidgetChangeAgreeTerm ↔ WidgetChangePaymentCallback?
getter/setter pair
onWidgetChangePayment ↔ WidgetChangePaymentCallback?
getter/setter pair
onWidgetReady ↔ BootpayCloseCallback?
getter/setter pair
onWidgetResize ↔ WidgetResizeCallback?
getter/setter pair
payload ↔ Payload?
getter/setter pair
paymentResult ↔ BootpayPaymentResult
getter/setter pair
readyWatch → String
no setter
renderWidgetJS → String
no setter
requestType ↔ int?
getter/setter pair
resizeWatch → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton ↔ bool?
getter/setter pair
userAgent ↔ String?
getter/setter pair
WIDGET_URL → String
latefinal
widgetHeight ↔ double
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BootpayWebView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
loadWidgetScript(String url) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushInternalWebView() → Future<void>
reloadWidget() → void
위젯 재로드 (에러/취소 후 재시도 시 사용)
removePaymentWindow() → void
requestPayment({Payload? payload, BootpayDefaultCallback? onError, BootpayDefaultCallback? onCancel, BootpayCloseCallback? onClose, BootpayDefaultCallback? onIssued, BootpayConfirmCallback? onConfirm, BootpayAsyncConfirmCallback? onConfirmAsync, BootpayDefaultCallback? onDone}) → Future<void>
setLocale(String locale) → void
setPrivateWidgetEvent(BuildContext context) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transactionConfirm() → void
widgetStatusReset() → void
widgetUpdate(Payload? payload, bool? refresh) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited