BootpayWebViewState class

Inheritance
Available extensions

Constructors

BootpayWebViewState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
params ↔ PlatformWebViewControllerCreationParams
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → BootpayWebView
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildPaymentUI() → Widget
buildWidgetUI() → Widget

Available on BootpayWebViewState, provided by the PaymentWidget extension

clickCloseButton() → void

Available on BootpayWebViewState, provided by the BootpayMethod extension

deactivate() → void
Called when this object is removed from the tree.
inherited
debounceClose() → void

Available on BootpayWebViewState, provided by the BootpayMethod extension

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant BootpayWebView oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getAnalyticsData() → Future<String>

Available on BootpayWebViewState, provided by the BootpayMethod extension

getBootpayJS() → String

Available on BootpayWebViewState, provided by the BootpayMethod extension

getBootpayJSBeforeContentLoaded() → Future<List<String>>

Available on BootpayWebViewState, provided by the BootpayMethod extension

goConfirmEvent(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

init() → void
initState() → void
Called when this object is inserted into the tree.
override
loadPaymentScript(String url) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCancelJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onCloseJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onConfirmJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onDoneJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onErrorJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onIssuedJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onProgressShow(bool isShow) → void

Available on BootpayWebViewState, provided by the BootpayCallback extension

onRedirectJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onWidgetChangeAgreeTermJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onWidgetChangePaymentJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onWidgetReadyJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

onWidgetResizeJS(JavaScriptMessage message) → Future<void>

Available on BootpayWebViewState, provided by the BootpayCallback extension

platformWebViewWidget() → Widget
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removePaymentWindow() → void

Available on BootpayWebViewState, provided by the BootpayMethod extension

setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
skeletonWidget() → Widget

Available on BootpayWebViewState, provided by the PaymentWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited