menu
bootpay package
documentation
config/bootpay_config.dart
BootpayConfig class
BootpayConfig class
dark_mode
light_mode
BootpayConfig
class
Constructors
BootpayConfig
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Static Properties
DISPLAY_WITH_HYBRID_COMPOSITION
↔
bool
getter/setter pair
ENV
↔
int
WebView 결제 환경. ENV_DEBUG(-1) | ENV_STAGE(-2) | ENV_PROMOTION(1=production). 기본값은 항상 ENV_PROMOTION. 배포 시 절대 변경하지 말 것. 로컬 테스트는
Bootpay.setEnvironmentMode('development')
등을 런타임에 호출.
getter/setter pair
IS_FORCE_WEB
↔
bool
getter/setter pair
Constants
ENV_DEBUG
→ const
int
ENV_PROMOTION
→ const
int
ENV_STAGE
→ const
int
VERSION
→ const
String
bootpay package
documentation
config/bootpay_config
BootpayConfig class
bootpay_config library