Payload class

Constructors

Payload({String? webApplicationId, String? androidApplicationId, String? iosApplicationId, String? clientKey, String? pg, String? method, List<String>? methods, String? orderName, String? currency, double? price, double? taxFree, double? depositPrice, String? orderId, String? subscriptionId, String? authenticationId, Map<String, dynamic>? metadata, String? userToken, Extra? extra, User? user, List<Item>? items, String? widgetKey, bool? widgetUseTerms, bool? widgetSandbox, Oopay? widgetOopay})
Payload.fromJson(Map<String, dynamic> json)

Properties

androidApplicationId ↔ String?
getter/setter pair
authenticationId ↔ String?
getter/setter pair
clientKey ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
depositPrice ↔ double?
getter/setter pair
extra ↔ Extra?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosApplicationId ↔ String?
getter/setter pair
items ↔ List<Item>?
getter/setter pair
metadata ↔ Map<String, dynamic>?
getter/setter pair
method ↔ String?
getter/setter pair
methods ↔ List<String>?
getter/setter pair
orderId ↔ String?
getter/setter pair
orderName ↔ String?
getter/setter pair
pg ↔ String?
getter/setter pair
price ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId ↔ String?
getter/setter pair
taxFree ↔ double?
getter/setter pair
user ↔ User?
getter/setter pair
userToken ↔ String?
getter/setter pair
webApplicationId ↔ String?
getter/setter pair
widgetIsCompleted → bool
no setter
widgetKey ↔ String?
getter/setter pair
widgetOopay ↔ Oopay?
getter/setter pair
widgetSandbox ↔ bool?
getter/setter pair
widgetUseTerms ↔ bool?
getter/setter pair

Methods

getApplicationId() → dynamic
getItems() → String
getMetadataString() → String
getMetadataStringAndroid() → String
getMethods() → String
getMethodValue() → String
getSelectTermsValue() → String
mergeWidgetData(WidgetData? data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reVal(dynamic value) → dynamic
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited