WidgetData class

Constructors

WidgetData({String? pg, String? method, String? walletId, List<WidgetTerm>? selectTerms, String? currency, bool? termPassed, bool? completed, WidgetExtra? extra, String? methodOriginSymbol, String? methodSymbol, String? easyPay, String? cardQuota})
WidgetData.fromJson(Map<String, dynamic> json)

Properties

cardQuota ↔ String?
getter/setter pair
completed ↔ bool?
getter/setter pair
currency ↔ String?
getter/setter pair
easyPay ↔ String?
getter/setter pair
extra ↔ WidgetExtra?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
method ↔ String?
getter/setter pair
methodOriginSymbol ↔ String?
getter/setter pair
methodSymbol ↔ String?
getter/setter pair
pg ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectTerms ↔ List<WidgetTerm>?
getter/setter pair
termPassed ↔ bool?
getter/setter pair
walletId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited