WidgetTerm class

Constructors

WidgetTerm({String? termId, String? pk, String? title, bool? agree, int? termType})
WidgetTerm.fromJson(Map<String, dynamic> json)

Properties

agree ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pk ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termId ↔ String?
getter/setter pair
termType ↔ int?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited