BootpayWidgetPaymentPage class

위젯 결제 전체화면 페이지 (Web용) Web에서는 JS SDK를 직접 사용하므로 별도 페이지가 필요없지만 호환성을 위해 stub 제공

Inheritance

Constructors

BootpayWidgetPaymentPage({Key? key, required Payload payload, BootpayDefaultCallback? onCancel, BootpayDefaultCallback? onError, BootpayCloseCallback? onClose, BootpayDefaultCallback? onIssued, BootpayConfirmCallback? onConfirm, BootpayAsyncConfirmCallback? onConfirmAsync, BootpayDefaultCallback? onDone})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel → BootpayDefaultCallback?
final
onClose → BootpayCloseCallback?
final
onConfirm → BootpayConfirmCallback?
final
onConfirmAsync → BootpayAsyncConfirmCallback?
final
onDone → BootpayDefaultCallback?
final
onError → BootpayDefaultCallback?
final
onIssued → BootpayDefaultCallback?
final
payload → Payload
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BootpayWidgetPaymentPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited